# Generated by Django 4.2.11 on 2024-06-07 13:41

# Django
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("ledger", "0001_initial"),
    ]

    operations = [
        migrations.DeleteModel(
            name="CorpSteuer",
        ),
        migrations.AlterModelOptions(
            name="characteraudit",
            options={
                "default_permissions": (),
                "permissions": (
                    ("char_audit_admin_access", "Has access to all characters"),
                    ("char_audit_manager", "Has access to all characters for own Corp"),
                ),
            },
        ),
        migrations.AlterModelOptions(
            name="corporationaudit",
            options={
                "default_permissions": (),
                "permissions": (
                    ("corp_audit_admin_access", "Has access to all Corporations"),
                    ("corp_audit_manager", "Has access to own Corporation"),
                ),
            },
        ),
        migrations.AlterModelOptions(
            name="general",
            options={
                "default_permissions": (),
                "managed": False,
                "permissions": (
                    ("basic_access", "Can access this app, Ledger."),
                    ("admin_access", "Has access to all Administration tools"),
                ),
            },
        ),
    ]
