{% extends 'allianceauth/base-bs5.html' %}
{% load i18n %}

{% block main_css %}
{% endblock main_css %}
{% block extra_css %}
{% endblock extra_css %}

{% block page_title %}
    {% block page_template_title %}{% endblock page_template_title %} ⋗ {% translate "Ledger" %}
{% endblock %}

{% block header_nav_brand %}
    <a class="nav-link text-white link-light link-underline link-underline-opacity-0" href="{% url 'ledger:index' %}">Ledger</a>
{% endblock header_nav_brand %}

{% block header_nav_collapse_left %}

{% include 'ledger/partials/menu/navigation.html' %}

{% endblock header_nav_collapse_left %}

{% block header_nav_collapse_right %}

{% include 'ledger/partials/menu/administration.html' %}

{% endblock header_nav_collapse_right %}

{% block content %}

{% include 'ledger/bundles/ledger-css.html' %}
{% include 'bundles/datatables-css-bs5.html' %}

<div class="allianceauth-ledger-plugin">
    <div class="card card-ledger">
    {% block ledger_block %}{% endblock %}
    </div>
    <br>
</div>

{% endblock %}

{% block extra_javascript %}
{% endblock %}

{% block extra_script %}
{% endblock %}
