{% load sri %}
{% load i18n %}

<!-- Chart Resources -->
<script src="https://cdn.amcharts.com/lib/version/5.13.4/index.js"></script>
<script src="https://cdn.amcharts.com/lib/version/5.13.4/xy.js"></script>
<script src="https://cdn.amcharts.com/lib/version/5.13.4/themes/Animated.js"></script>
<script src="https://cdn.amcharts.com/lib/version/5.13.4/themes/Dark.js"></script>
<script src="https://cdn.amcharts.com/lib/version/5.13.4/percent.js"></script>
<script src="https://cdn.amcharts.com/lib/version/5.13.4/flow.js"></script>

<script>
    // Embed translations in a global JavaScript object
    window.translations = {
        months: [
            "{% trans 'January' %}", "{% trans 'February' %}", "{% trans 'March' %}", "{% trans 'April' %}",
            "{% trans 'May' %}", "{% trans 'June' %}", "{% trans 'July' %}", "{% trans 'August' %}",
            "{% trans 'September' %}", "{% trans 'October' %}", "{% trans 'November' %}", "{% trans 'December' %}"
        ],
        dayText: "{% trans 'Day' %}",
        monthText: "{% trans 'Month' %}"
    };
</script>
