.progress-outer {
    position: relative;
    background: white;
    border-radius: 50px;
    box-shadow: 0 0 10px rgb(0 219 231 / 70%);
    overflow: hidden; /* Ensure the inner progress bar doesn't overflow */
}

.progress {
    height: 27px;
    margin: 0;
    overflow: visible;
    border-radius: 50px;
    background: rgb(234 237 243);
    box-shadow: inset 0 10px 10px rgb(244 245 250 / 90%);
}

.progress .progress-bar {
    border-radius: 50px;
}

.progress .progress-value {
    position: absolute;
    left: 50%;
    top: 50%;
    transform: translate(-50%, -50%);
    font-size: 16px;
    font-weight: bold;
    color: white;
    letter-spacing: 2px;
    -webkit-text-stroke: 1px black;
}

.progress-bar.active {
    animation: reverse progress-bar-stripes 0.40s linear infinite, animate-positive 2s;
}

@keyframes animate-positive {
    0% { width: 0%; }
}
