{% load i18n %}
{% load evelinks %}

{% if character %}
    <div>
        <h4 id="modal-title">
            {{ information }}
        </h4>
    </div>
    <div>
        <ul class="nav nav-tabs" id="ledger-character-info" role="tablist">
            <li class="nav-item">
                <a class="nav-link bg-secondary active" href="#tab-summary" data-bs-toggle="tab" role="tab" data-bs-target="#tab-summary">{% trans "Summary" %}</a>
            </li>
            <li class="nav-item">
                <a class="nav-link bg-secondary" href="#tab-daily" data-bs-toggle="tab" role="tab" data-bs-target="#tab-daily">{% trans "Daily" %}</a>
            </li>
            <li class="nav-item">
                <a class="nav-link bg-secondary" href="#tab-hourly" data-bs-toggle="tab" role="tab" data-bs-target="#tab-hourly">{% trans "Hourly" %}</a>
            </li>
        </ul>
        <div class="card-body bg-secondary rounded-bottom tab-content px-2 mb-3">
            {% include "ledger/partials/information/summary.html" with character=character type=type %}
            {% include "ledger/partials/information/daily.html" with character=character type=type %}
            {% include "ledger/partials/information/hourly.html" with character=character type=type %}
        </div>
    </div>
{% elif error %}
    <div class="alert alert-danger">
        <h4 class="alert-heading">{% trans "Error" %}</h4>
        <p>{{ error }}</p>
    </div>
{% else %}
    {% trans "No ratting data found..." %}
{% endif %}
