# Generated by Django 4.2.20 on 2025-05-04 21:51

# Django
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("ledger", "0010_fetch_planets_and_update_planetdetails"),
    ]

    operations = []
