{% extends "ledger/base.html" %}
{% load i18n %}

{% block page_template_title %}
    {{ title }}
{% endblock page_template_title %}

{% block page_topic %}
    <h1 class="page-header text-center">
        {{ title }}
    </h1>
{% endblock page_topic %}

{% block ledger_block %}
    <div class="card-body">
        <div class="card bg-secondary">
            <div class="card-header text-center bg-primary">{% translate "Administration" %}</div>
            <div class="card-body w-25">
                <form action="{% url 'ledger:admin' %}" method="post">
                    {% csrf_token %}
                    <div class="mb-3 form-check">
                        <input class="form-check-input" type="checkbox" name="force_refresh" id="force_refresh">
                        <label class="form-check-label" for="force_refresh">{% translate "Mark all tasks as Force Refresh" %}</label>
                    </div>
                    <hr class="my-4"> <!-- Bootstrap Trennlinie -->
                    <div class="mb-3 form-check">
                        <input class="form-check-input" type="checkbox" name="run_clear_etag" id="run_clear_etag">
                        <label class="form-check-label" for="run_clear_etag">{% translate "Clear all cached ETags" %}</label>
                    </div>
                    <div class="mb-3 form-check">
                        <input class="form-check-input" type="checkbox" name="run_char_updates" id="run_char_updates">
                        <label class="form-check-label" for="run_char_updates">{% translate "Update Character Updates" %}</label>
                    </div>
                    <div class="mb-3 form-check">
                        <input class="form-check-input" type="checkbox" name="run_corp_updates" id="run_corp_updates">
                        <label class="form-check-label" for="run_corp_updates">{% translate "Update Corp Updates" %}</label>
                    </div>
                    <input type="submit" value="{% translate 'Submit' %}" class="btn col-md-12 btn-primary" />
                </form>
            </div>
        </div>
    </div>
{% endblock ledger_block %}
