{% load i18n %}
{% load navactive %}

<li class="nav-item">
    <a class="nav-link py-0" href="{% url 'ledger:add_char' %}">
        <span class="btn btn-success">{% translate 'Add Character' %}</span>
    </a>
</li>

{% if perms.ledger.manage_access %}
    <li class="nav-item">
        <a class="nav-link py-0" href="{% url 'ledger:add_corp' %}">
            <span class="btn btn-success">{% translate 'Add Corporation' %}</span>
        </a>
    </li>

    <li class="nav-item">
        <a class="nav-link py-0" href="{% url 'ledger:add_ally' %}">
            <span class="btn btn-success">{% translate 'Add Alliance' %}</span>
        </a>
    </li>
{% endif %}
