{% extends 'ledger/base.html' %}
{% load i18n %}

{% block page_template_title %}
    {{ title }}
{% endblock page_template_title %}

{% block page_topic %}
    <h1 class="page-header text-center">
        {{ title }}
    </h1>
{% endblock page_topic %}

{% block ledger_block %}
    <div class="card card-alliance-administration">
        <div class="card-header bg-primary rounded-top d-flex align-items-center">
            <h3 class="me-3">{% translate "Administration" %}</h3>
        </div>
        <!-- Content -->
        <div id="ledger-index" class="card-body rounded-bottom fade">
            <div class="card-body">
                <div class="row">
                    <div class="col-lg-6 col-md-12">
                        {% include 'ledger/partials/administration/dashboard.html' %}
                    </div>
                    <div class="col-lg-6 col-md-12">
                        {% include 'ledger/partials/administration/alliance.html' %}
                    </div>
                </div>
            </div>
            <div class="card-body">
                <div class="card-header bg-primary rounded-top d-flex align-items-center mt-4">
                    <h3 class="text-white">{% translate "Corporations" %}</h3>
                </div>
                <div class="card-body bg-secondary">
                    {% include 'ledger/partials/administration/alliance_corporations.html' %}
                </div>
            </div>
        </div>
    </div>
{% endblock %}

{% block extra_javascript %}
    {% include 'bundles/datatables-js-bs5.html' %}
    {% include 'ledger/bundles/ally-administration-bundles.html' %}
{% endblock %}
