# Generated by Django 4.2.11 on 2025-01-30 22:59

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("ledger", "0007_characterplanetdetails_facilitys"),
    ]

    operations = [
        migrations.AlterField(
            model_name="characterminingledger",
            name="date",
            field=models.DateTimeField(),
        ),
    ]
