# Generated by Django 4.2.23 on 2025-07-14 09:04

# Django
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("ledger", "0012_alter_corporationwalletjournalentry_division"),
    ]

    operations = [
        migrations.DeleteModel(
            name="Events",
        ),
    ]
