{% load i18n %}
{% load humanize %}
{% load evelinks %}

<!--##############################DAILY#######################-->

{% for key, label in character.income_types %}
    {% with value=character|get_item:key %}
        {% if value.current_day %}
            <div class="row description-row">
                <div class="col-sm-6 {% if label == 'Not Defined Category' %}text-warning{% endif %}">{% trans "Current Day -" %} {{ label }}:</div>
                <div class='col-sm-4 text-end'>
                    <span class="{% if not key == 'mining_income' %}text-success{% else %}text-info{% endif %}">
                        {{ value.current_day|floatformat:0|intcomma }}
                    </span> ISK
                </div>
            </div>
        {% endif %}
    {% endwith %}
{% endfor %}

<!--############################## Costs #######################-->

{% for key, label in character.cost_types %}
    {% with value=character|get_item:key %}
        {% if value.current_day %}
            <div class="row description-row">
                <div class="col-sm-6 {% if label == 'Not Defined Category' %}text-warning{% endif %}">{% trans "Current Day Cost -" %} {{ label }}:</div>
                <div class='col-sm-4 text-end'>
                    <span class="text-danger">{{ value.current_day|floatformat:0|intcomma }}</span> ISK
                </div>
            </div>
        {% endif %}
    {% endwith %}
{% endfor %}

<!--############################## SUMMARY Day #######################-->
{% if character.summary.total_current_day %}
    <hr>
    <div class="row description-row">
        <div class="col-sm-6">{% trans "Current Day" %} {% trans "Summary" %}:</div>
        <div class='col-sm-4 text-end'>
            <span class="text-warning">
            {{ character.summary.total_current_day|floatformat:0|intcomma }}
            </span> ISK
        </div>
    </div>
{% endif %}
