# Generated by Django 4.2.11 on 2025-05-26 06:53

# Django
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("ledger", "0011_create_update_status_existings"),
    ]

    operations = [
        migrations.AlterField(
            model_name="corporationwalletjournalentry",
            name="division",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="ledger_corporation_journal",
                to="ledger.corporationwalletdivision",
            ),
        ),
    ]
