{% extends 'ledger/base.html' %}
{% load i18n %}
{% load sri %}

{% block page_template_title %}
    {{ title }}
{% endblock page_template_title %}

{% block page_topic %}
    <h1 class="page-header text-center">
        {{ title }}
    </h1>
{% endblock page_topic %}

{% block ledger_block %}
    <div class="card-body bg-primary rounded-top d-flex">
        <h3>{% translate "Planetary Details" %} </h3>
        <div class="ms-auto">
            <a class="nav-link py-0" href="{% url 'ledger:planetary_overview' %}">
                <span class="btn btn-secondary">{% translate 'Planetary Overview' %}</span>
            </a>
        </div>
    </div>
    <div id="ledger-index" class="card-body rounded-bottom fade">
        <div class="card-body bg-secondary table-responsive">
            <span>
                <i class="fa-solid fa-bullhorn"></i> {% trans "Notification" %} <span class="text-success">{% trans "ON" %}</span>/<span class="text-danger">{% trans "OFF" %}</span>
            </span>
            {% include 'ledger/partials/table/planetary.html' %}
            <button id="turn-all-notification" type="button" class="btn btn-primary btn-sm btn-square me-2 d-none"
                data-bs-toggle="modal"
                data-tooltip-toggle="planetary"
                data-character-id="0"
                data-planet-id="0"
                data-title="{% translate 'Toggle Alarm' %}"
                data-text="{% translate 'Are you sure to Turn On/Off all Notifications?' %}"
                data-bs-target="#ledger-planetary-confirm"
                data-action="{% url 'ledger:switch_alarm' %}" aria-label="Toggle Alarm"
                >
                <span class="fas fa-bullhorn"></span> {% translate 'Turn All On/Off' %}
            </button>
        </div>
    </div>
{% endblock %}

{% block extra_javascript %}
    {% include 'ledger/bundles/planetary-bundles.html' %}
{% endblock %}

{% block extra_css %}
{% endblock %}

{% block extra_script %}
{% endblock %}
