{% load i18n %}

<table class="table table-dark table-striped table-hover w-100" id="planets-details">
    <thead>
        <th class="col-character w-auto">{% translate "Character" %}</th>
        <th class="col-planet-type w-auto">{% translate "Planet" %}</th>
        <th class="col-upgrade-level w-auto">{% translate "Upgrade Level" %}</th>
        <th class="col-products w-auto no-sort">{% translate "Products" %}</th>
        <th class="col-progress w-auto">{% translate "Progress" %}</th>
        <th class="col-extractor w-auto no-sort">{% translate "Extractor" %}</th>
        <th class="col-Status w-auto no-sort">{% translate "Status" %}</th>
        <th class="col-Last-Updated w-auto">{% translate "Last Updated" %}</th>
        <th class="col-Actions w-auto no-sort">{% translate "Actions" %}</th>
    </thead>

    <tbody>
    </tbody>
</table>
