# Generated by Django 4.2.23 on 2025-08-28 05:19

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("ledger", "0015_rename_character_characteraudit_eve_character"),
    ]

    operations = [
        migrations.AddField(
            model_name="characterminingledger",
            name="price_per_unit",
            field=models.DecimalField(
                decimal_places=2, default=None, max_digits=20, null=True
            ),
        ),
    ]
